#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem
from math import degrees

mol = oechem.OEMol()
o = mol.NewAtom(oechem.OEElemNo_O)
h1 = mol.NewAtom(oechem.OEElemNo_H)
h2 = mol.NewAtom(oechem.OEElemNo_H)

Acrds = [0.0, 0.0, 0.0,
         0.9584, 0.0, 0.0,
         -0.2392, 0.9281, 0.0]
# Grab the default conformer
Aconf = mol.GetConfs().next()
Aconf.SetCoords(oechem.OEFloatArray(Acrds))

Bcrds = [0.0, 0.0, 0.0,
         0.9584, 0.0, 0.0,
         -0.2392, -0.9281, 0.0]
Bconf = mol.NewConf(oechem.OEFloatArray(Bcrds))

print("1st Water Angle:", degrees(oechem.OEGetAngle(Aconf, h1, o, h2)))
print("2nd Water Angle:", degrees(oechem.OEGetAngle(Bconf, h1, o, h2)))
# @ </SNIPPET>
